@@ -1,11 +1,17 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 python-hcalendar is a basic hCalendar parser
 """
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
 
 __version_info__ = {
     'major': 0,
     'minor': 2,
-    'micro': 0,
+    'micro': 2,
     'releaselevel': 'final',
 }
 
